@@ -35,11 +35,58 @@ typedef enum {
 /* This is exactly the style information you've been looking for */
 #define GTK_STYLE_PROVIDER_PRIORITY_FORCE G_MAXUINT
 
+static char *arg_output_dir = NULL;
+static char *arg_base_dir = NULL;
+static char *arg_direction = NULL;
+
+static const GOptionEntry test_args[] = {
+  { "output",         'o', 0, G_OPTION_ARG_FILENAME, &arg_output_dir,
+    "Directory to save image files to", "DIR" },
+  { "directory",        'd', 0, G_OPTION_ARG_FILENAME, &arg_base_dir,
+    "Directory to run tests from", "DIR" },
+  { "direction",       0, 0, G_OPTION_ARG_STRING, &arg_direction,
+    "Set text direction", "DIRECTION" },
+  { NULL }
+};
+
+static const char *
+get_output_dir (void)
+{
+  static const char *output_dir = NULL;
+  GError *error = NULL;
+
+  if (output_dir)
+    return output_dir;
+
+  if (arg_output_dir)
+    {
+      GFile *file = g_file_new_for_commandline_arg (arg_output_dir);
+      output_dir = g_file_get_path (file);
+      g_object_unref (file);
+    }
+  else
+    {
+      output_dir = g_get_tmp_dir ();
+    }
+
+  if (!g_file_test (output_dir, G_FILE_TEST_EXISTS))
+    {
+      GFile *file;
+
+      file = g_file_new_for_path (output_dir);
+      g_assert (g_file_make_directory_with_parents (file, NULL, &error));
+      g_assert_no_error (error);
+      g_object_unref (file);
+    }
+
+  return output_dir;
+}
+
 static char *
 get_output_file (const char *test_file,
                  const char *extension)
 {
-  const char *output_dir = g_get_tmp_dir ();
+  const char *output_dir = get_output_dir ();
   char *result, *base;
 
   base = g_path_get_basename (test_file);
@@ -440,7 +487,8 @@ test_ui_file (GFile *file)
 					      datetime,
 					      G_DESKTOP_CLOCK_FORMAT_24H,
 					      TRUE, TRUE, TRUE);
-  g_test_message ("Date string is: '%s'", str);
+  /* If you need to copy/paste to a .ref.ui file, uncomment here
+   * g_message ("str: %s", str); */
   g_date_time_unref (datetime);
   g_object_unref (clock);
 
@@ -559,7 +607,7 @@ main (int argc, char **argv)
   g_test_init (&argc, &argv, NULL);
   gtk_init (&argc, &argv);
 
-  basedir = INSTALLED_TEST_DIR;
+  basedir = g_test_get_dir (G_TEST_DIST);
   file = g_file_new_for_commandline_arg (basedir);
   add_test_for_file (file);
   g_object_unref (file);
